def eikonal(xyz,ax=[0,0.01,101],ay=[0,0.01,101],az=[0,0.01,101],order=2):
	'''
	eikonal: Fast marching eikonal solver (3-D)
	
	INPUT
	xyz:
	ax: axis x
	ay: axis y
	az: axis z
	
	OUTPUT
	times: traveltime (numpy array)
	
	EXAMPLE
	
	'''
	
	times=[]

	return times